Package: MBNMAtime
Type: Package
Title: Run Time-Course Model-Based Network Meta-Analysis (MBNMA) Models
Version: 0.2.6
Language: en-GB
Date: 2025-01-28
Authors@R: c(person("Hugo", "Pedder", 
    email = "hugopedder@gmail.com", 
    role = c("aut", "cre"),
    comment = c(ORCID = "0000-0002-7813-3749")))
Maintainer: Hugo Pedder <hugopedder@gmail.com>
Description: Fits Bayesian time-course models for model-based network meta-analysis (MBNMA) that allows inclusion of multiple
  time-points from studies. Repeated measures over time are accounted for within studies by applying different time-course functions,
  following the method of Pedder et al. (2019) <doi:10.1002/jrsm.1351>. 
  The method allows synthesis of studies with multiple follow-up measurements that can account for time-course for a single or multiple 
  treatment comparisons. Several general time-course functions are provided; others may be added 
  by the user. Various characteristics can be flexibly added to the models, such as correlation between time points and shared 
  class effects. The consistency of direct and indirect evidence in the network can be assessed using unrelated mean effects 
  models and/or by node-splitting.
License: GPL-3
Depends: R (>= 3.5.0)
Imports: knitr, grDevices, stats, graphics, utils, grid, gridExtra,
        dplyr (>= 0.7.4), R2jags (>= 0.8-9), rjags (>= 4-8), reshape2
        (>= 1.4.3), magrittr (>= 1.5), checkmate (>= 1.8.5), igraph (>=
        2.0.1.1), scales (>= 1.0.0), lspline(>= 1.0-0), crayon (>=
        1.3.4), ggplot2 (>= 2.2.1), ggdist (>= 2.4.0), png, zoo (>=
        1.8-8), Rdpack (>= 0.10-1)
Suggests: overlapping (>= 1.5.0), splines (>= 4.0.2), Hmisc (>= 4.4-1),
        rmarkdown, testthat (>= 1.0.2), RColorBrewer (>= 1.1-2),
        mcmcplots (>= 0.4.3)
SystemRequirements: JAGS (>= 4.3.0) (http://mcmc-jags.sourceforge.net)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.2.3
VignetteBuilder: knitr, rmarkdown
RdMacros: Rdpack
URL: https://hugaped.github.io/MBNMAtime/
NeedsCompilation: no
Packaged: 2025-01-28 17:27:04 UTC; hp17602
Author: Hugo Pedder [aut, cre] (<https://orcid.org/0000-0002-7813-3749>)
Repository: CRAN
Date/Publication: 2025-01-29 00:10:10 UTC
Built: R 4.6.0; ; 2026-04-29 04:46:37 UTC; unix
