# Generated by roxygen2: do not edit by hand

S3method(plot,mb.network)
S3method(plot,mb.predict)
S3method(plot,mb.rank)
S3method(plot,mbnma)
S3method(plot,nodesplit)
S3method(predict,mbnma)
S3method(print,mb.network)
S3method(print,mb.predict)
S3method(print,mb.rank)
S3method(print,nodesplit)
S3method(print,relative.array)
S3method(rank,mb.predict)
S3method(rank,mbnma)
S3method(summary,mb.network)
S3method(summary,mb.predict)
S3method(summary,mbnma)
S3method(summary,nodesplit)
export("%>%")
export(add_index)
export(binplot)
export(cumrank)
export(default.priors)
export(devplot)
export(fitplot)
export(genspline)
export(get.closest.time)
export(get.earliest.time)
export(get.latest.time)
export(get.prior)
export(get.relative)
export(getjagsdata)
export(getnmadata)
export(inconsistency.loops)
export(mb.comparisons)
export(mb.make.contrast)
export(mb.network)
export(mb.nodesplit)
export(mb.nodesplit.comparisons)
export(mb.run)
export(mb.update)
export(mb.write)
export(nma.run)
export(rank)
export(ref.synth)
export(temax)
export(tfpoly)
export(timeplot)
export(titp)
export(tloglin)
export(tpoly)
export(tspline)
export(tuser)
export(write.ref.synth)
importFrom(Rdpack,reprompt)
importFrom(magrittr,"%>%")
